PresetCardData class

Data passed to each PresetCard widget.

Constructors

PresetCardData({required DotMatrixPreset preset, required String name, required String description, required String tag, required String category})
const

Properties

category String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
preset DotMatrixPreset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited